# AXRoleConstants.h Documentation

## Overview
This header defines the string constants used to specify the role of an accessibility object.

## Constants

| Constant Name | Description |
| :--- | :--- |
| `kAXApplicationRole` | An application. |
| `kAXBrowserRole` | An accessibility object that displays column-based, hierarchically structured data, such as the column view in a Finder window. |
| `kAXButtonRole` | A button. |
| `kAXCheckBoxRole` | A check box. |
| `kAXColumnRole` | A column. |
| `kAXDrawerRole` | A drawer. |
| `kAXGrowAreaRole` | A grow control. |
| `kAXImageRole` | An image. |
| `kAXMenuButtonRole` | A menu button. |
| `kAXOutlineRole` | An accessibility object that displays row-based, hierarchically structured data, such as the list view in a Finder window. |
| `kAXPopUpButtonRole` | A pop-up button. |
| `kAXRadioButtonRole` | A radio button. |
| `kAXRowRole` | A row. |
| `kAXSheetRole` | A sheet. |
| `kAXSystemWideRole` | The system-wide accessibility object. |
| `kAXTabGroupRole` | A tab view. |
| `kAXTableRole` | A table. |
| `kAXUnknownRole` | Generic role value for an unknown accessibility object. |
| `kAXWindowRole` | A window. |
